# YouTube Downloader

This is a simple YouTube downloader that uses the `pytube` library to download videos from YouTube. It is a simple command line application that takes a YouTube video URL and downloads the video to the current working directory.

## Installation

To install the application, you can use the following command:

```bash
pip install git+hhttps://github.com/henishpatel9045/youtube-downloader.git
```

## Usage

To use the application, you can run the following command:

```bash
yt-downloader
```